@@ -104,7 +104,7 @@ class IntrospectionModule(object):
         info = repository.find_by_name(self._namespace, name)
         if not info:
             raise AttributeError("%r object has no attribute %r" % (
-                    self.__name__, name))
+                                 self.__name__, name))
 
         if isinstance(info, EnumInfo):
             g_type = info.get_g_type()
@@ -131,8 +131,8 @@ class IntrospectionModule(object):
                 # identifier conversion (e. g. in Turkish 'i'.upper() == 'i')
                 # see https://bugzilla.gnome.org/show_bug.cgi?id=649165
                 ascii_upper_trans = maketrans(
-                        'abcdefgjhijklmnopqrstuvwxyz',
-                        'ABCDEFGJHIJKLMNOPQRSTUVWXYZ')
+                    'abcdefgjhijklmnopqrstuvwxyz',
+                    'ABCDEFGJHIJKLMNOPQRSTUVWXYZ')
                 for value_info in info.get_values():
                     value_name = value_info.get_name().translate(ascii_upper_trans)
                     setattr(wrapper, value_name, wrapper(value_info.get_value()))
@@ -154,7 +154,7 @@ class IntrospectionModule(object):
             if isinstance(info, ObjectInfo):
                 parent = get_parent_for_object(info)
                 interfaces = tuple(interface for interface in get_interfaces_for_object(info)
-                        if not issubclass(parent, interface))
+                                   if not issubclass(parent, interface))
                 bases = (parent,) + interfaces
                 metaclass = GObjectMeta
             elif isinstance(info, CallbackInfo):
@@ -166,9 +166,9 @@ class IntrospectionModule(object):
             elif isinstance(info, (StructInfo, UnionInfo)):
                 if g_type.is_a(_gobject.TYPE_BOXED):
                     bases = (Boxed,)
-                elif g_type.is_a(_gobject.TYPE_POINTER) or \
-                     g_type == _gobject.TYPE_NONE or \
-                     g_type.fundamental == g_type:
+                elif (g_type.is_a(_gobject.TYPE_POINTER) or
+                      g_type == _gobject.TYPE_NONE or
+                      g_type.fundamental == g_type):
                     bases = (Struct,)
                 else:
                     raise TypeError("unable to create a wrapper for %s.%s" % (info.get_namespace(), info.get_name()))
@@ -261,9 +261,9 @@ class DynamicModule(object):
     def __repr__(self):
         path = repository.get_typelib_path(self._namespace)
         return "<%s.%s %r from %r>" % (self.__class__.__module__,
-                                      self.__class__.__name__,
-                                      self._namespace,
-                                      path)
+                                       self.__class__.__name__,
+                                       self._namespace,
+                                       path)
 
 
 class DynamicGObjectModule(DynamicModule):
