@@ -204,19 +204,21 @@ class TestGLib(unittest.TestCase):
         self.assertEqual(variant.unpack(), obj)
 
         obj = {"frequency": GLib.Variant('t', 738000000),
-            "hierarchy": GLib.Variant('i', 0),
-            "bandwidth": GLib.Variant('x', 8),
-            "code-rate-hp": GLib.Variant('d', 2.0 / 3.0),
-            "constellation": GLib.Variant('s', "QAM16"),
-            "guard-interval": GLib.Variant('u', 4)}
+               "hierarchy": GLib.Variant('i', 0),
+               "bandwidth": GLib.Variant('x', 8),
+               "code-rate-hp": GLib.Variant('d', 2.0 / 3.0),
+               "constellation": GLib.Variant('s', "QAM16"),
+               "guard-interval": GLib.Variant('u', 4)}
         variant = GLib.Variant('a{sv}', obj)
         self.assertEqual(variant.get_type_string(), 'a{sv}')
-        self.assertEqual(variant.unpack(), {"frequency": 738000000,
-            "hierarchy": 0,
-            "bandwidth": 8,
-            "code-rate-hp": 2.0 / 3.0,
-            "constellation": "QAM16",
-            "guard-interval": 4})
+        self.assertEqual(variant.unpack(),
+                         {"frequency": 738000000,
+                          "hierarchy": 0,
+                          "bandwidth": 8,
+                          "code-rate-hp": 2.0 / 3.0,
+                          "constellation": "QAM16",
+                          "guard-interval": 4
+                         })
 
     def test_gvariant_create_errors(self):
         # excess arguments
@@ -230,6 +232,7 @@ class TestGLib(unittest.TestCase):
         self.assertRaises(TypeError, GLib.Variant, 'i', 'hello')
         self.assertRaises(TypeError, GLib.Variant, 's', 42)
         self.assertRaises(TypeError, GLib.Variant, '(ss)', 'mec', 'mac')
+        self.assertRaises(TypeError, GLib.Variant, '(s)', 'hello')
 
         # unimplemented data type
         self.assertRaises(NotImplementedError, GLib.Variant, 'Q', 1)
@@ -257,7 +260,7 @@ class TestGLib(unittest.TestCase):
 
         # tuple
         res = GLib.Variant.new_tuple(GLib.Variant.new_int32(-1),
-                GLib.Variant.new_string('hello')).unpack()
+                                     GLib.Variant.new_string('hello')).unpack()
         self.assertEqual(res, (-1, 'hello'))
 
         # array
@@ -293,7 +296,7 @@ class TestGLib(unittest.TestCase):
 
         # tuple index access
         v = GLib.Variant.new_tuple(GLib.Variant.new_int32(-1),
-                GLib.Variant.new_string('hello'))
+                                   GLib.Variant.new_string('hello'))
         self.assertEqual(len(v), 2)
         self.assertEqual(v[0], -1)
         self.assertEqual(v[1], 'hello')
@@ -350,15 +353,15 @@ class TestGLib(unittest.TestCase):
         self.assertEqual(GLib.Variant.split_signature('(iso)'), ['i', 's', 'o'])
 
         self.assertEqual(GLib.Variant.split_signature('(s(ss)i(ii))'),
-                ['s', '(ss)', 'i', '(ii)'])
+                         ['s', '(ss)', 'i', '(ii)'])
 
         self.assertEqual(GLib.Variant.split_signature('(as)'), ['as'])
 
         self.assertEqual(GLib.Variant.split_signature('(s(ss)iaiaasa(ii))'),
-                ['s', '(ss)', 'i', 'ai', 'aas', 'a(ii)'])
+                         ['s', '(ss)', 'i', 'ai', 'aas', 'a(ii)'])
 
         self.assertEqual(GLib.Variant.split_signature('(a{iv}(ii)((ss)a{s(ss)}))'),
-                ['a{iv}', '(ii)', '((ss)a{s(ss)})'])
+                         ['a{iv}', '(ii)', '((ss)a{s(ss)})'])
 
     def test_variant_hash(self):
         v1 = GLib.Variant('s', 'somestring')
@@ -644,12 +647,12 @@ class TestGtk(unittest.TestCase):
             ('test-action1', None, 'Test Action 1',
              None, None, test_action_callback_data),
             ('test-action2', Gtk.STOCK_COPY, 'Test Action 2',
-              None, None, test_action_callback_data)], callback_data)
+             None, None, test_action_callback_data)], callback_data)
         action_group.add_toggle_actions([
             ('test-toggle-action1', None, 'Test Toggle Action 1',
              None, None, test_action_callback_data, False),
             ('test-toggle-action2', Gtk.STOCK_COPY, 'Test Toggle Action 2',
-              None, None, test_action_callback_data, True)], callback_data)
+             None, None, test_action_callback_data, True)], callback_data)
         action_group.add_radio_actions([
             ('test-radio-action1', None, 'Test Radio Action 1'),
             ('test-radio-action2', Gtk.STOCK_COPY, 'Test Radio Action 2')], 1,
@@ -672,9 +675,7 @@ class TestGtk(unittest.TestCase):
     def test_uimanager(self):
         self.assertEqual(Gtk.UIManager, overrides.Gtk.UIManager)
         ui = Gtk.UIManager()
-        ui.add_ui_from_string(
-"""
-<ui>
+        ui.add_ui_from_string("""<ui>
     <menubar name="menubar1"></menubar>
 </ui>
 """
@@ -721,8 +722,7 @@ class TestGtk(unittest.TestCase):
         builder = Gtk.Builder()
 
         # add object1 to the builder
-        builder.add_from_string(
-"""
+        builder.add_from_string("""
 <interface>
   <object class="GIOverrideSignalTest" id="object1">
       <signal name="test-signal" after="yes" handler="on_signal_after" />
@@ -732,8 +732,7 @@ class TestGtk(unittest.TestCase):
 """)
 
         # only add object3 to the builder
-        builder.add_objects_from_string(
-"""
+        builder.add_objects_from_string("""
 <interface>
   <object class="GIOverrideSignalTest" id="object2">
       <signal name="test-signal" handler="on_signal_2" />
@@ -745,9 +744,7 @@ class TestGtk(unittest.TestCase):
       <signal name="test-signal" handler="on_signal_4" />
   </object>
 </interface>
-
-""",
-            ['object3'])
+""", ['object3'])
 
         # hook up signals
         builder.connect_signals(signal_checker)
@@ -761,6 +758,42 @@ class TestGtk(unittest.TestCase):
         self.assertEqual(signal_checker.sentinel, 4)
         self.assertEqual(signal_checker.after_sentinel, 2)
 
+    def test_window(self):
+        # standard Window
+        w = Gtk.Window()
+        self.assertEqual(w.get_property('type'), Gtk.WindowType.TOPLEVEL)
+
+        # type works as keyword argument
+        w = Gtk.Window(type=Gtk.WindowType.POPUP)
+        self.assertEqual(w.get_property('type'), Gtk.WindowType.POPUP)
+
+        # pygtk compatible positional argument
+        w = Gtk.Window(Gtk.WindowType.POPUP)
+        self.assertEqual(w.get_property('type'), Gtk.WindowType.POPUP)
+
+        class TestWindow(Gtk.Window):
+            __gtype_name__ = "TestWindow"
+
+        # works from builder
+        builder = Gtk.Builder()
+        builder.add_from_string('''
+<interface>
+  <object class="GtkWindow" id="win">
+    <property name="type">popup</property>
+  </object>
+  <object class="TestWindow" id="testwin">
+  </object>
+  <object class="TestWindow" id="testpop">
+    <property name="type">popup</property>
+  </object>
+</interface>''')
+        self.assertEqual(builder.get_object('win').get_property('type'),
+                         Gtk.WindowType.POPUP)
+        self.assertEqual(builder.get_object('testwin').get_property('type'),
+                         Gtk.WindowType.TOPLEVEL)
+        self.assertEqual(builder.get_object('testpop').get_property('type'),
+                         Gtk.WindowType.POPUP)
+
     def test_dialogs(self):
         self.assertEqual(Gtk.Dialog, overrides.Gtk.Dialog)
         self.assertEqual(Gtk.AboutDialog, overrides.Gtk.AboutDialog)
@@ -1216,14 +1249,14 @@ class TestGtk(unittest.TestCase):
         label = 'this is row #102'
         treeiter = list_store.append()
         list_store.set(treeiter, (1, 0, 2, 3, 4, 5, 6, 7),
-                                  (label,
-                                   i,
-                                   TestGtk.TestClass(self, i, label),
-                                   test_pyobj,
-                                   test_pydict,
-                                   test_pylist,
-                                   0,
-                                   False))
+                                 (label,
+                                  i,
+                                  TestGtk.TestClass(self, i, label),
+                                  test_pyobj,
+                                  test_pydict,
+                                  test_pylist,
+                                  0,
+                                  False))
 
         self.assertEqual(len(list_store), 103)
 
@@ -1278,16 +1311,16 @@ class TestGtk(unittest.TestCase):
 
         # not sorted yet, should be original order
         self.assertEqual([list(i) for i in list_store],
-                [[1, 'apples'], [3, 'oranges'], [2, 'mango']])
+                         [[1, 'apples'], [3, 'oranges'], [2, 'mango']])
 
         # sort with our custom function
         list_store.set_sort_column_id(2, Gtk.SortType.ASCENDING)
         self.assertEqual([list(i) for i in list_store],
-                [[2, 'mango'], [1, 'apples'], [3, 'oranges']])
+                         [[2, 'mango'], [1, 'apples'], [3, 'oranges']])
 
         list_store.set_sort_column_id(2, Gtk.SortType.DESCENDING)
         self.assertEqual([list(i) for i in list_store],
-                [[3, 'oranges'], [1, 'apples'], [2, 'mango']])
+                         [[3, 'oranges'], [1, 'apples'], [2, 'mango']])
 
     def test_list_store_signals(self):
         list_store = Gtk.ListStore(int, bool)
@@ -1343,8 +1376,7 @@ class TestGtk(unittest.TestCase):
         p2 = Gtk.TreePath.new_from_string('1:2:3')
         self.assertEqual(p1, p2)
         self.assertEqual(str(p1), '1:2:3')
-        self.assertTrue(p1 != None)
-        self.assertFalse(p1 == None)
+        self.assertNotEqual(p1, None)
         self.assertTrue(p1 > None)
         self.assertTrue(p1 >= None)
         self.assertFalse(p1 < None)
@@ -1691,7 +1723,7 @@ class TestGtk(unittest.TestCase):
         self.assertTrue(start.has_tag(tag))
 
         self.assertRaises(ValueError, buffer.insert_with_tags_by_name,
-                buffer.get_start_iter(), 'HelloHello', 'unknowntag')
+                          buffer.get_start_iter(), 'HelloHello', 'unknowntag')
 
     def test_text_iter(self):
         self.assertEqual(Gtk.TextIter, overrides.Gtk.TextIter)
@@ -1762,7 +1794,7 @@ class TestGtk(unittest.TestCase):
                 for kl in classes:
                     if kl.get_name() == name:
                         self.assertTrue(issubclass(klass, over,),
-                            "%r does not inherit from override %r" % (klass, over,))
+                                        "%r does not inherit from override %r" % (klass, over,))
 
     def test_editable(self):
         self.assertEqual(Gtk.Editable, overrides.Gtk.Editable)
